@@ -17,11 +17,11 @@ from typing import (
     List,
     Tuple,
     TypeVar,
-    Self,
     TypedDict,
-    Unpack
 )
 
+from typing_extensions import Self, Unpack
+
 from trueconf import loggers
 from trueconf.client.session import WebSocketSession
 from trueconf.dispatcher.dispatcher import Dispatcher
